summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/khighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/khighscore.h')
-rw-r--r--libkdegames/highscore/khighscore.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdegames/highscore/khighscore.h b/libkdegames/highscore/khighscore.h
index ba7a4bd0..b7b6fb5e 100644
--- a/libkdegames/highscore/khighscore.h
+++ b/libkdegames/highscore/khighscore.h
@@ -90,7 +90,7 @@ public:
* Constructor. The highscore file is forced to be local to support
* games using the old behaviour.
*/
- KHighscore(TQObject* tqparent = 0);
+ KHighscore(TQObject* parent = 0);
/**
* Constructor.
@@ -98,10 +98,10 @@ public:
* @param forceLocal if true, the local highscore file is used even
* when the configuration has been set to use a system-wide file. This
* is convenient for converting highscores from legacy applications.
* @param tqparent tqparent widget for this widget
* @since 3.2
*/
- KHighscore(bool forceLocal, TQObject *tqparent);
+ KHighscore(bool forceLocal, TQObject *parent);
/**
* Read the current state of the highscore file. Remember that when
@@ -133,7 +133,7 @@ public:
* If the config file cannot be locked,
* the method waits for 1 second and, if it failed again, displays
* a message box asking for retry or cancel.
* @param widget used as the tqparent of the message box.
*
* @return false on error or if the config file is locked by another
* process. In such case, the config stays read-only.
@@ -98,10 +98,10 @@ public:
* when the configuration has been set to use a system-wide file. This
* is convenient for converting highscores from legacy applications.
- * @param tqparent tqparent widget for this widget
+ * @param parent parent widget for this widget
* @since 3.2
*/
@@ -133,7 +133,7 @@ public:
* the method waits for 1 second and, if it failed again, displays
* a message box asking for retry or cancel.
- * @param widget used as the tqparent of the message box.
+ * @param widget used as the parent of the message box.
*
* @return false on error or if the config file is locked by another